Documentation
¶
Overview ¶
+k8s:deepcopy-gen=package +groupName=kubeflow.org
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme SchemeGroupVersion = schema.GroupVersion{Group: groupName, Version: version} SchemeGroupVersionKind = schema.GroupVersionKind{Group: groupName, Version: version, Kind: kind} )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource.
Types ¶
type MPIJob ¶
type MPIJob struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec MPIJobSpec `json:"spec,omitempty"`
Status MPIJobStatus `json:"status,omitempty"`
}
func (*MPIJob) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MPIJob.
func (*MPIJob) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MPIJob) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MPIJobLauncherStatusType ¶
type MPIJobLauncherStatusType string
const ( // LauncherActive means the MPIJob launcher is actively running. LauncherActive MPIJobLauncherStatusType = "Active" // LauncherSucceeded means the MPIJob launcher has succeeded. LauncherSucceeded MPIJobLauncherStatusType = "Succeeded" // LauncherFailed means the MPIJob launcher has failed its execution. LauncherFailed MPIJobLauncherStatusType = "Failed" )
These are valid launcher statuses of an MPIJob.
type MPIJobList ¶
type MPIJobList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []MPIJob `json:"items"`
}
func (*MPIJobList) DeepCopy ¶
func (in *MPIJobList) DeepCopy() *MPIJobList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MPIJobList.
func (*MPIJobList) DeepCopyInto ¶
func (in *MPIJobList) DeepCopyInto(out *MPIJobList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MPIJobList) DeepCopyObject ¶
func (in *MPIJobList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MPIJobSpec ¶
type MPIJobSpec struct {
// Specifies the desired number of GPUs the MPIJob should run on.
// Mutually exclusive with the `Replicas` field.
// +optional
GPUs *int32 `json:"gpus,omitempty"`
// Run the launcher on the master.
// Optional: Default to false
// +optional
LauncherOnMaster bool `json:"launcherOnMaster,omitempty"`
// Optional number of retries before marking this job failed.
// Defaults to 6
// +optional
BackoffLimit *int32 `json:"backoffLimit,omitempty"`
// Specifies the desired number of replicas the MPIJob should run on.
// The `PodSpec` should specify the number of GPUs.
// Mutually exclusive with the `GPUs` field.
// +optional
Replicas *int32 `json:"replicas,omitempty"`
// Describes the pod that will be created when executing an MPIJob.
Template corev1.PodTemplateSpec `json:"template,omitempty"`
}
func (*MPIJobSpec) DeepCopy ¶
func (in *MPIJobSpec) DeepCopy() *MPIJobSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MPIJobSpec.
func (*MPIJobSpec) DeepCopyInto ¶
func (in *MPIJobSpec) DeepCopyInto(out *MPIJobSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MPIJobStatus ¶
type MPIJobStatus struct {
// Current status of the launcher job.
// +optional
LauncherStatus MPIJobLauncherStatusType `json:"launcherStatus,omitempty"`
// The number of available worker replicas.
// +optional
WorkerReplicas int32 `json:"workerReplicas,omitempty"`
}
func (*MPIJobStatus) DeepCopy ¶
func (in *MPIJobStatus) DeepCopy() *MPIJobStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MPIJobStatus.
func (*MPIJobStatus) DeepCopyInto ¶
func (in *MPIJobStatus) DeepCopyInto(out *MPIJobStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.